pub struct BatchMapping { /* private fields */ }Expand description
Mapping from call index to batch result index.
When calls are batched, we need to track which result corresponds to which original call for reconstructing per-call outputs.
Implementations
Sourceimpl BatchMapping
impl BatchMapping
Sourcepub fn from_collector(collector: &BatchCollector) -> Self
pub fn from_collector(collector: &BatchCollector) -> Self
Create a new mapping from a collector.